@@ -1,9 +1,8 @@
-#$Id: MMagic.pm,v 1.68 2011/03/02 03:05:47 papu Exp $
-# "File::MMagic" version 1.26 $$
-
+# $Id: MMagic.pm,v 1.480 2012/03/18 06:03:51 papu Exp $
+# "File::MMagic" version 1.27 $$
 # File::MMagic
 #
-# Id: MMagic.pm 198 2006-01-30 05:24:17Z knok
+# Id: MMagic.pm 259 2006-05-23 05:55:32Z knok
 #
 # This program is originated from file.kulp that is a production of The
 # Unix Reconstruction Projct.
@@ -80,7 +79,7 @@
 #  * 4. The names "Apache Server" and "Apache Group" must not be used to
 #  *    endorse or promote products derived from this software without
 #  *    prior written permission. For written permission, please contact
-#  *    apache (at) apache (dot) org.
+#  *    <apache (at) apache (dot) org>.
 #  *
 #  * 5. Products derived from this software may not be called "Apache"
 #  *    nor may "Apache" appear in their names without prior written
@@ -103,19 +102,14 @@
 #  * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 #  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 #  * OF THE POSSIBILITY OF SUCH DAMAGE.
-
 package File::MMagic;
-
-
 use FileHandle;
 use strict;
-
 use vars qw(
 %TEMPLATES %ESC $VERSION
 $magicFile $checkMagic $followLinks $fileList
 $allowEightbit
 );
-
 BEGIN {
 # translation of type in magic file to unpack template and byte count
 %TEMPLATES = (byte     => [ 'c', 1 ],
@@ -138,18 +132,15 @@ BEGIN {
 		 lelong   => [ [ 'V', 'I', 'i' ], 4 ],
 		 ledate   => [   'V',             4 ],
 		 string   => undef);
-
 # for letter escapes in magic file
 %ESC = ( n => "\n",
 	    r => "\r",
 	    b => "\b",
 	    t => "\t",
 	    f => "\f");
-
-$VERSION = "1.26";
+$VERSION = "1.27";
 $allowEightbit = 1;
 }
-
 sub new {
     my $self = {};
     my $proto = shift;
@@ -161,14 +152,12 @@ sub new {
 	binmode($fh);
 	bless $fh, 'FileHandle' if ref $fh ne 'FileHandle';
 	my $dataLoc;
-
 	{
 	    no strict 'refs';
 	    my $instance = \${ "$class\::_instance" };
 	    $$instance = $fh->tell() unless $$instance;
 	    $dataLoc = $$instance;
 	}
-
 	$fh->seek($dataLoc, 0);
 	&readMagicHandle($self, $fh);
     } else {
@@ -181,22 +170,20 @@ sub new {
 	    warn __PACKAGE__ . " couldn't load specified file $filename";
 	}
     }
-
 # from the BSD names.h, some tokens for hard-coded checks of
 # different texts.  This isn't rocket science.  It's prone to
 # failure so these checks are only a last resort.
-
 # removSpecials() can be used to remove those afterwards.
     $self->{SPECIALS} = {
-		 "message/rfc822" => [ "^Received:",   
-			     "^>From ",       
-			     "^From ",       
+		 "message/rfc822" => [ "^Received:",
+			     "^>From ",
+			     "^From ",
 			     "^To: ",
 			     "^Return-Path: ",
 			     "^Cc: ",
 			     "^X-Mailer: "],
-		 "message/news" => [ "^Newsgroups: ", 
-			     "^Path: ",       
+		 "message/news" => [ "^Newsgroups: ",
+			     "^Path: ",
 			     "^X-Newsreader: "],
 		 "text/html" => [ "<html[^>]*>",
 			     "<HTML[^>]*>",
@@ -220,7 +207,6 @@ sub new {
 			      "^\\.IR ",
 				   ],
 		};
-
     $self->{FILEEXTS} = {
 	     '\.gz$' => 'application/x-gzip',
 	     '\.bz2$' => 'application/x-bzip2',
@@ -232,14 +218,12 @@ sub new {
     bless($self);
     return $self;
 }
-
 sub addSpecials {
     my $self = shift;
     my $mtype = shift;
     $self->{SPECIALS}->{"$mtype"} = [@_];
     return $self;
 }
-
 sub removeSpecials {
     my $self = shift;
     # Remove all keys if no arguments given
@@ -250,7 +234,6 @@ sub removeSpecials {
     }
     return %returnmtypes;
 }
-
 sub addFileExts {
     my $self = shift;
     my $filepat = shift;
@@ -258,18 +241,16 @@ sub addFileExts {
     $self->{FILEEXTS}->{"$filepat"} = $mtype;
     return $self;
 }
-
 sub removeFileExts {
     my $self = shift;
     # Remove all keys if no arguments given
-    my @filepats = (@_ or keys %{$self->{FILEEXTS}}); 
+    my @filepats = (@_ or keys %{$self->{FILEEXTS}});
     my %returnfilepats;
     foreach my $filepat (@filepats) {
       $returnfilepats{"$filepat"} = delete $self->{FILEEXTS}->{"$filepat"};
     }
     return %returnfilepats;
 }
-
 sub addMagicEntry {
     my $self = shift;
     my $entry = shift;
@@ -289,7 +270,6 @@ sub addMagicEntry {
     unshift @{$self->{magic}}, [$entry, -1, []];
     return $self;
 }
-
 sub readMagicHandle {
     my $self = shift;
     my $fh = shift;
@@ -298,30 +278,24 @@ sub readMagicHandle {
     $self->{MF}->[2] = 0;
     readMagicEntry($self->{magic}, $self->{MF});
 }
-
 # Not implimented.
 #
 #sub readMagicFile {
 #    my $self = shift;
 #    my $mfile = shift;
 #}
-
 sub checktype_filename {
     my $self = shift;
-
 # iterate over each file explicitly so we can seek
     my $file = shift;
-
     # the description line.  append info to this string
     my $desc;
     my $mtype;
-
     # 0) check permission
     if (! -r $file) {
 	$desc .= " can't read `$file': Permission denied.";
 	return "x-system/x-error; $desc";
     }
-
     # 1) check for various special files first
     if ($^O eq 'MSWin32') {
 	stat($file);
@@ -329,8 +303,8 @@ sub checktype_filename {
 	if ($followLinks) { stat($file); } else { lstat($file); }
     }
     if (! -f _  or -z _) {
-	if ( $^O ne 'MSWin32' && !$followLinks && -l _ ) { 
-	    $desc .= " symbolic link to ".readlink($file); 
+	if ( $^O ne 'MSWin32' && !$followLinks && -l _ ) {
+	    $desc .= " symbolic link to ".readlink($file);
 	}
 	elsif ( -d _ ) { $desc .= " directory"; }
 	elsif ( -p _ ) { $desc .= " named pipe"; }
@@ -339,56 +313,36 @@ sub checktype_filename {
 	elsif ( -c _ ) { $desc .= " character special file"; }
 	elsif ( -z _ ) { $desc .= " empty"; }
 	else { $desc .= " special"; }
-
 	return "x-system/x-unix; $desc";
     }
-
     # current file handle.  or undef if checkMagic (-c option) is true.
     my $fh;
-
 #    $fh = new FileHandle "< $file" or die "$F: $file: $!\n" ;
     $fh = new FileHandle "< $file" or return "x-system/x-error; $file: $!\n" ;
-
     binmode($fh); # for MSWin32
-
     # 2) check for script
     if (-x $file && -T _) {
-
-
-
-
 	my $line1 = <$fh>;
 	if ($line1 =~ /^\#!\s*(\S+)/) {
 	    $desc .= " executable $1 script text";
 	}
 	else { $desc .= " commands text"; }
-
 	$fh->close();
-
 	return "x-system/x-unix; $desc";
-
     }
-
     my $out = checktype_filehandle($self, $fh, $desc);
     undef $fh;
-
     return $out;
 }
-
 sub checktype_filehandle {
     my $self = shift;
     my ($fh, $desc) = @_;
     my $mtype;
-
     binmode($fh); # for MSWin32 architecture.
-
     # 3) iterate over each magic entry.
     my $matchFound = 0;
     my $m;
     for ($m = 0; $m <= $#{$self->{magic}}; $m++) {
-
-
-
 	if (magicMatch($self->{magic}->[$m],\$desc,$fh)) {
 	    if (defined $desc && $desc ne '') {
 		$matchFound = 1;
@@ -396,15 +350,10 @@ sub checktype_filehandle {
 		last;
 	    }
 	}
-
-
-
-
 	if ($m == $#{$self->{magic}} && !$self->{MF}->[0]->eof()) {
 	    readMagicEntry($self->{magic}, $self->{MF});
 	}
     }
-
     # 4) check if it's text or binary.
     # if it's text, then do a bunch of searching for special tokens
     if (!$matchFound) {
@@ -413,82 +362,57 @@ sub checktype_filehandle {
 	$fh->read($data, 0x8564);
 	$mtype = checktype_data($self, $data);
     }
-
     $mtype = 'text/plain' if (! defined $mtype);
-
     return $mtype;
 }
-
 sub checktype_contents {
     my $self = shift;
     my $data = shift;
     my $mtype;
-
     return 'application/octet-stream' if (length($data) <= 0);
-
     $mtype = checktype_magic($self, $data);
-
     # 4) check if it's text or binary.
     # if it's text, then do a bunch of searching for special tokens
     if (!defined $mtype) {
 	$mtype = checktype_data($self, $data);
     }
-
     $mtype = 'text/plain' if (! defined $mtype);
-
     return $mtype;
 }
-
 sub checktype_magic {
     my $self = shift;
     my $data = shift;
     my $desc;
     my $mtype;
-
     return 'application/octet-stream' if (length($data) <= 0);
-
     # 3) iterate over each magic entry.
     my $m;
     for ($m = 0; $m <= $#{$self->{magic}}; $m++) {
-
-
-
 	if (magicMatchStr($self->{magic}->[$m],\$desc,$data)) {
 	    if (defined $desc && $desc ne '') {
 		$mtype = $desc;
 		last;
 	    }
 	}
-
-
-
-
 	if ($m == $#{$self->{magic}} && !$self->{MF}->[0]->eof()) {
 	    readMagicEntry($self->{magic}, $self->{MF});
 	}
     }
-
     return $mtype;
 }
-
 sub checktype_data {
     my $self = shift;
     my $data = shift;
     my $mtype;
-
     return undef if (length($data) <= 0);
-
     # truncate data
     $data = substr($data, 0, 0x8564);
-
     # at first, check SPECIALS
     {
-
-
 	my %val;
 	foreach my $type (keys %{$self->{SPECIALS}}) {
 	    my $matched_pos = undef;
-	    foreach my $token (@{$self->{SPECIALS}->{$type}}){ 
+	    foreach my $token (@{$self->{SPECIALS}->{$type}}){
 		pos($data) = 0;
 		if ($data =~ /$token/mg) {
 		    my $tmp =  pos($data);
@@ -499,26 +423,22 @@ sub checktype_data {
 	    }
 	    $val{$type} = $matched_pos if $matched_pos;
 	}
-
 	if (%val) {
 	    my @skeys = sort { $val{$a} <=> $val{$b} } keys %val;
 	    $mtype = $skeys[0];
 	}
-	
+#	$mtype = 'text/plain' if (! defined $mtype);
     }
     if (! defined $mtype && check_binary($data)) {
 	$mtype = "application/octet-stream";
     }
-	
 #    $mtype = 'text/plain' if (! defined $mtype);
     return $mtype;
 }
-
 sub checktype_byfilename {
     my $self = shift;
     my $fname = shift;
     my $type;
-
     $fname =~ s/^.*\///;
     for my $regex (keys %{$self->{FILEEXTS}}) {
 	if ($fname =~ /$regex/i) {
@@ -530,7 +450,6 @@ sub checktype_byfilename {
     $type = 'application/octet-stream' unless defined $type;
     return $type;
 }
-
 sub check_binary {
     my ($data) = @_;
     my $len = length($data);
@@ -545,7 +464,6 @@ sub check_binary {
     }
     return 0;
 }
-
 sub check_magic {
     my $self = shift @_;
     # read the whole file if we haven't already
@@ -554,40 +472,34 @@ sub check_magic {
     }
     dumpMagic($self->{magic});
 }
-
 ####### SUBROUTINES ###########
-
 # compare the magic item with the filehandle.
 # if success, print info and return true.  otherwise return undef.
 #
 # this is called recursively if an item has subitems.
 sub magicMatch {
     my ($item, $p_desc, $fh) = @_;
-
     # delayed evaluation.  if this is our first time considering
     # this item, then parse out its structure.  @$item is just the
     # raw string, line number, and subtests until we need the real info.
     # this saves time otherwise wasted parsing unused subtests.
-    $item = readMagicLine(@$item) if @$item == 3;
-
+    if (@$item == 3){
+        my $tmp = readMagicLine(@$item);
+        @$item = @$tmp;
+    }
     # $item could be undef if we ran into troubles while reading
     # the entry.
     return unless defined($item);
-
     # $fh is not be defined if -c.  that way we always return
     # false for every item which allows reading/checking the entire
     # magic file.
     return unless defined($fh);
-    
-    my ($offtype, $offset, $numbytes, $type, $mask, $op, $testval, 
+    my ($offtype, $offset, $numbytes, $type, $mask, $op, $testval,
 	$template, $message, $subtests) = @$item;
-
     # bytes from file
     my $data;
-
     # set to true if match
     my $match = 0;
-
     # offset = [ off1, sz, template, off2 ] for indirect offset
     if ($offtype == 1) {
 	my ($off1, $sz, $template, $off2) = @$offset;
@@ -597,18 +509,12 @@ sub magicMatch {
 	$fh->seek($off2,0) or return;
     }
     elsif ($offtype == 2) {
-
 	$fh->seek($offset,1) or return;
     }
     else {
-
 	$fh->seek($offset,0) or return;
     }
-
     if ($type =~ /^string/) {
-
-
-
 	if ($numbytes > 0) {
 	    if ($fh->read($data,$numbytes) != $numbytes) { return; }
 	}
@@ -619,8 +525,6 @@ sub magicMatch {
 		$ch = $fh->getc();
 	    }
 	}
-
-
 	if ($op eq '=') {
 	    $match = ($data eq $testval);
 	}
@@ -630,23 +534,12 @@ sub magicMatch {
 	elsif ($op eq '>') {
 	    $match = ($data gt $testval);
 	}
-
-
 	if ($checkMagic) {
 	    print STDERR "STRING: $data $op $testval => $match\n";
 	}
-
     }
     else {
-
-
-
 	if ($fh->read($data,$numbytes) != $numbytes) { return; }
-
-
-
-
-
 	if (ref($template)) {
 	    $data = unpack($$template[2],
 			   pack($$template[1],
@@ -655,13 +548,9 @@ sub magicMatch {
 	else {
 	    $data = unpack($template,$data);
 	}
-
-
 	if (defined($mask)) {
 	    $data &= $mask;
 	}
-
-
 	if ($op eq '=') {
 	    $match = ($data == $testval);
 	}
@@ -683,69 +572,49 @@ sub magicMatch {
 	elsif ($op eq '>') {
 	    $match = ($data > $testval);
 	}
-
-
 	if ($checkMagic) {
 	    print STDERR "NUMERIC: $data $op $testval => $match\n";
 	}
-
     }
-
     if ($match) {
-
-
-
 	if ($message =~ s/^\\b//) {
 	    $$p_desc .= sprintf($message,$data);
 	}
 	else {
+#	    $$p_desc .= ' ' . sprintf($message,$data) if $message;
 	    $$p_desc .= sprintf($message,$data) if $message;
 	}
-
 	my $subtest;
 	foreach $subtest (@$subtests) {
 	    magicMatch($subtest,$p_desc,$fh);
 	}
-
 	return 1;
     }
-    
 }
-
 sub magicMatchStr {
     my ($item, $p_desc, $str) = @_;
     my $origstr = $str;
-
     # delayed evaluation.  if this is our first time considering
     # this item, then parse out its structure.  @$item is just the
     # raw string, line number, and subtests until we need the real info.
     # this saves time otherwise wasted parsing unused subtests.
     if (@$item == 3){
 	my $tmp = readMagicLine(@$item);
-
-
-
 	return unless defined($tmp);
-
 	@$item = @$tmp;
     }
-
     # $fh is not be defined if -c.  that way we always return
     # false for every item which allows reading/checking the entire
     # magic file.
     return unless defined($str);
     return if ($str eq '');
-    
-    my ($offtype, $offset, $numbytes, $type, $mask, $op, $testval, 
+    my ($offtype, $offset, $numbytes, $type, $mask, $op, $testval,
 	$template, $message, $subtests) = @$item;
     return unless defined $op;
-
     # bytes from file
     my $data;
-
     # set to true if match
     my $match = 0;
-
     # offset = [ off1, sz, template, off2 ] for indirect offset
     if ($offtype == 1) {
 	my ($off1, $sz, $template, $off2) = @$offset;
@@ -755,19 +624,13 @@ sub magicMatchStr {
 	return if (length($str) < $off2);
     }
     elsif ($offtype == 2) {
-
 	return;
     }
     else {
-
 	return if ($offset > length($str));
 	$str = substr($str, $offset);
     }
-
     if ($type =~ /^string/) {
-
-
-
 	if ($numbytes > 0) {
 	    $data = pack("a$numbytes", $str);
 	}
@@ -775,8 +638,6 @@ sub magicMatchStr {
 	    $str =~ /^(.*)\0|$/;
 	    $data = $1;
 	}
-
-
 	if ($op eq '=') {
 	    $match = ($data eq $testval);
 	}
@@ -786,24 +647,13 @@ sub magicMatchStr {
 	elsif ($op eq '>') {
 	    $match = ($data gt $testval);
 	}
-
-
 	if ($checkMagic) {
 	    print STDERR "STRING: $data $op $testval => $match\n";
 	}
-
     }
     else {
-
-
-
         return if (length($str) < 4);
 	$data = substr($str, 0, 4);
-
-
-
-
-
 	if (ref($template)) {
 	    $data = unpack($$template[2],
 			   pack($$template[1],
@@ -812,13 +662,9 @@ sub magicMatchStr {
 	else {
 	    $data = unpack($template,$data);
 	}
-
-
 	if (defined($mask)) {
 	    $data &= $mask;
 	}
-
-
 	if ($op eq '=') {
 	    $match = ($data == $testval);
 	}
@@ -840,36 +686,26 @@ sub magicMatchStr {
 	elsif ($op eq '>') {
 	    $match = ($data > $testval);
 	}
-
-
 	if ($checkMagic) {
 	    print STDERR "NUMERIC: $data $op $testval => $match\n";
 	}
-
     }
-
     if ($match) {
-
-
-
 	if ($message =~ s/^\\b//) {
 	    $$p_desc .= sprintf($message,$data);
 	}
 	else {
+#	    $$p_desc .= ' ' . sprintf($message,$data) if $message;
 	    $$p_desc .= sprintf($message,$data) if $message;
 	}
-
 	my $subtest;
 	foreach $subtest (@$subtests) {
 	    # finish evaluation when matched.
 	    magicMatchStr($subtest,$p_desc,$origstr);
 	}
-
 	return 1;
     }
-    
 }
-
 # readMagicEntry($pa_magic, $MF, $depth)
 #
 # reads the next entry from the magic file and stores it as
@@ -883,13 +719,10 @@ sub magicMatchStr {
 #
 sub readMagicEntry {
     my ($pa_magic, $MF, $depth) = @_;
-
     # for some reason I need a local var because <$$MF[0]> doesn't work.(?)
     my $magicFH = $$MF[0];
-
     # a ref to an array containing a magic line's components
     my ($entry, $line);
-
     $line = $$MF[1];
     while (1) {
 	$line = '' if (! defined $line);
@@ -899,14 +732,11 @@ sub readMagicEntry {
 	    $$MF[2]++;
 	    next;
 	}
-	
 	my ($thisDepth) = ($line =~ /^(>+)/);
 	$thisDepth = '' if (! defined $thisDepth);
 	$depth = 0 if (! defined $depth);
-
 	if (length($thisDepth) > $depth) {
 	    $$MF[1] = $line;
-
 	    # call ourselves recursively.  will return the depth
 	    # of the entry following the nested group.
 	    if ((readMagicEntry($entry->[2], $MF, $depth+1) || 0) < $depth ||
@@ -929,15 +759,12 @@ sub readMagicEntry {
 	else {
 	    # we're here if the number of '>' is the same as the
 	    # current depth and we haven't read a magic line yet.
-
 	    # create temp entry
 	    # later -- if we ever get around to evaluating this condition --
 	    # we'll replace @$entry with the results from readMagicLine.
 	    $entry = [ $line , $$MF[2], [] ];
-
 	    # add to list
 	    push(@$pa_magic,$entry);
-
 	    # read the next line
 	    last if $magicFH->eof();
 	    $line = <$magicFH>;
@@ -945,7 +772,6 @@ sub readMagicEntry {
 	}
     }
 }
-
 # readMagicLine($line, $line_num, $subtests)
 #
 # parses the match info out of $line.  Returns a reference to an array.
@@ -959,38 +785,29 @@ sub readMagicEntry {
 #
 sub readMagicLine {
     my ($line, $line_num, $subtests) = @_;
-
-    my ($offtype, $offset, $numbytes, $type, $mask, 
+    my ($offtype, $offset, $numbytes, $type, $mask,
 	$operator, $testval, $template, $message);
-    
     # this would be easier if escaped whitespace wasn't allowed.
-
     # grab the offset and type.  offset can either be a decimal, oct,
     # or hex offset or an indirect offset specified in parenthesis
     # like (x[.[bsl]][+-][y]), or a relative offset specified by &.
     # offtype : 0 = absolute, 1 = indirect, 2 = relative
-    if ($line =~ s/^>*([&\(]?[a-flsx\.\+\-\d]+\)?)\s+(\S+)\s+//) {
+    if ($line =~ s/^>*([&\(]?[a-fA-Flsx\.\+\-\d]+\)?)\s+(\S+)\s+//) {
 	($offset,$type) = ($1,$2);
-
 	if ($offset =~ /^\(/) {
-	    # indirect offset.  
+	    # indirect offset.
 	    $offtype = 1;
-
 	    # store as a reference [ offset1 type template offset2 ]
-
 	    my ($o1,$type,$o2);
 	    if (($o1,$type,$o2) = ($offset =~ /\((\d+)(\.[bsl])?([\+\-]?\d+)?\)/))
 	    {
 		$o1 = oct($o1) if $o1 =~ /^0/o;
 		$o2 = oct($o2) if $o2 =~ /^0/o;
-
 		$type =~ s/\.//;
 		if ($type eq '') { $type = 'l'; }  # default to long
 		$type =~ tr/b/c/; # type will be template for unpack
-
 		my $sz = $type;	  # number of bytes
 		$sz =~ tr/csl/124/;
-
 		$offset = [ $o1,$sz,$type,int($o2) ];
 	    } else {
 		warn "Bad indirect offset at line $line_num. '$offset'\n";
@@ -1000,14 +817,12 @@ sub readMagicLine {
 	elsif ($offset =~ /^&/o) {
 	    # relative offset
 	    $offtype = 2;
-
 	    $offset = substr($offset,1);
 	    $offset = oct($offset) if $offset =~ /^0/o;
 	}
 	else {
 	    # normal absolute offset
 	    $offtype = 0;
-
 	    # convert if needed
 	    $offset = oct($offset) if $offset =~ /^0/o;
 	}
@@ -1016,21 +831,16 @@ sub readMagicLine {
 	warn "Bad Offset/Type at line $line_num. '$line'\n";
 	return;
     }
-    
     # check for & operator on type
     if ($type =~ s/&(.*)//) {
 	$mask = $1;
-
-
 	$mask = oct($mask) if $mask =~ /^0/o;
     }
-    
     # check if type is valid
     if (!exists($TEMPLATES{$type}) && $type !~ /^string/) {
 	warn "Invalid type '$type' at line $line_num\n";
 	return;
     }
-    
     # take everything after the first non-escaped space
     if ($line =~ s/([^\\])\s+(.*)/$1/) {
 	$message = $2;
@@ -1039,10 +849,8 @@ sub readMagicLine {
 	warn "Missing or invalid test condition or message at line $line_num\n";
 	return;
     }
-    
     # remove the return if it's still there
     $line =~ s/\n$//o;
-
     # get the operator.  if 'x', must be alone.  default is '='.
     if ($line =~ s/^([><&^=!])//o) {
 	$operator = $1;
@@ -1051,19 +859,10 @@ sub readMagicLine {
 	$operator = 'x';
     }
     else { $operator = '='; }
-    
-
     if ($type =~ /string/) {
 	$testval = $line;
-
-
 	$testval =~ s/\\([x0-7][0-7]?[0-7]?)/chr(oct($1))/eg;
-
-
 	$testval =~ s/\\(.)/$ESC{$1}||$1/eg;
-
-
-
 	if ($operator =~ /[>x]/o) {
 	    $numbytes = 0;
 	}
@@ -1088,7 +887,6 @@ sub readMagicLine {
 	}
     }
     else {
-
 	if ($operator ne 'x') {
 	    # this conversion is very forgiving.  it's faster and
 	    # it doesn't complain about bugs in popular magic files,
@@ -1099,40 +897,33 @@ sub readMagicLine {
 		$testval = int($line);
 	    }
 	}
-
 	($template,$numbytes) = @{$TEMPLATES{$type}};
-
-
 	if (ref($template)) {
 	    $template = $$template[0]
 	      unless $operator eq '>' || $operator eq '<';
 	}
     }
-    
     return [ $offtype, $offset, $numbytes, $type, $mask,
 	    $operator, $testval, $template, $message, $subtests ];
 }
-
 # recursively write the magic file to stderr.  Numbers are written
 # in decimal.
 sub dumpMagic {
     my ($magic,$depth) = @_;
     $magic = [] unless defined $magic;
     $depth = 0 unless defined $depth;
-
     my $entry;
     foreach $entry (@$magic) {
-
-	$entry = readMagicLine(@$entry) if @$entry == 3;
-
+        if (@$entry == 3){
+            my $tmp = readMagicLine(@$entry);
+            @$entry = @$tmp;
+        }
 	next if !defined($entry);
-
-	my ($offtype, $offset, $numbytes, $type, $mask, $op, $testval, 
+	my ($offtype, $offset, $numbytes, $type, $mask, $op, $testval,
 	    $template, $message, $subtests) = @$entry;
-
 	print STDERR '>'x$depth;
 	if ($offtype == 1) {
-	    $offset->[2] =~ tr/c/b/; 
+	    $offset->[2] =~ tr/c/b/;
 	    print STDERR "($offset->[0].$offset->[2]$offset->[3])";
 	}
 	elsif ($offtype == 2) {
@@ -1145,11 +936,9 @@ sub dumpMagic {
 	print STDERR "\t",$type;
 	if ($mask) { print STDERR "&",$mask; }
 	print STDERR "\t",$op,$testval,"\t",$message,"\n";
-
 	if ($subtests) {
 	    dumpMagic($subtests,$depth+1);
 	}
     }
 }
-
 1;
