@@ -1,15 +1,15 @@
 ######################################################################
 # antispamwiki.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: antispamwiki.inc.pl,v 1.41 2011/03/02 03:05:47 papu Exp $
+# $Id: antispamwiki.inc.pl,v 1.297 2011/12/31 13:06:09 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-rc6 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 by Nekyo.
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -33,35 +33,45 @@
 #   antispamwiki.inc.plantispamwiki.inc.cgi˥͡हǻȤޤ
 #
 ######################################################################
-
 # ͭ¡ʣ֡
 $AntiSpamWiki::expire=1*60*60
 	if(!defined($AntiSpamWiki::expire));
-
+#
+# û񤭹߻֡ʣá
+$AntiSpamWiki::mintime=5
+	if(!defined($AntiSpamWiki::mintime));
+#
 %::antispamwiki_cookie;
-$::antispamwiki_cookie="PyukiWikiAntiSpamWiki_"
-				. length($::basepath);
-
-# Initlize
-
+$::antispamwiki_cookie="PAW_"
+				. &dbmname($::basepath);
+$::antispamwiki_cookie_name="t";
+$::antispamwiki_cookie_expire=60*60*60;
+######################################################################
 sub plugin_antispamwiki_init {
+#	return('init'=>0)
 	my $stat=0;
 	%::antispamwiki_cookie=();
 	%::antispamwiki_cookie=&getcookie($::antispamwiki_cookie,%::antispamwiki_cookie);
 	my $time=time;
-	if($::antispamwiki_cookie{time} eq '') {
+	if($::antispamwiki_cookie{$::antispamwiki_cookie_name} eq '') {
 		$stat=1;
-	} elsif($::antispamwiki_cookie{time}+0+$AntiSpamWiki::expire < $time) {
+	} elsif($::antispamwiki_cookie{$::antispamwiki_cookie_name}+0+$AntiSpamWiki::expire < $time) {
+		$stat=-1;
+	} elsif($time-$::antispamwiki_cookie{$::antispamwiki_cookie_name}+0 < $AntiSpamWiki::mintime) {
 		$stat=-1;
 	}
+$::debug.="now:$time, cookie:$::antispamwiki_cookie{$::antispamwiki_cookie_name}\n";
 	if($stat+0 ne 0) {
-		if($::form{mymsg} ne '' || $ENV{REQUEST_METHOD}=~/[Pp][Oo][Ss][Tt]/) {
+		if($::form{mymsg} ne '' ||$::form{msg} ne '') {
 			$::form{cmd}="read";
 			$::form{mypage}=$::FrontPage;
 		}
 	}
-	my $js=qq(<script type="text/javascript">@{[!$::is_xhtml ? "<!--\n" : '']}document.cookie="$::antispamwiki_cookie=time%3a$time; path=$::basepath";@{[!$::is_xhtml ? '//-->' : '']}</script>\n);
-	return('init'=>1, 'header'=>$js);
+	$::antispamwiki_cookie{$::antispamwiki_cookie_name}=$time;
+	&setcookie($::antispamwiki_cookie,$::antispamwiki_cookie_expire,%::antispamwiki_cookie);
+#	my $js=qq(<script type="text/javascript"><!--\nd.cookie="$::antispamwiki_cookie=$::antispamwiki_cookie_name%3a$time; path=$::basepath";\n//--></script>\n);
+	return('init'=>1);
+#	return('init'=>1, 'header'=>$js);
 }
 1;
 __DATA__
@@ -70,8 +80,7 @@ sub plugin_antispamwiki_setup {
 	'ja'=>'Wikiѥߥɻ',
 	'en'=>'Anti Spam for WikiPlugin',
 	'override'=>'',
-	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/antispamwiki/'
+	'url'=>'http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/ExPlugin/antispamwiki/'
 	);
 }
 __END__
-
