@@ -1,16 +1,16 @@
 ######################################################################
-# autometarobot.inc.cgi - This is PyukiWiki, yet another Wiki clone.
-# $Id: autometarobot.inc.pl,v 1.77 2011/03/02 03:05:47 papu Exp $
+# autometarobot.inc.pl - This is PyukiWiki, yet another Wiki clone.
+# $Id: autometarobot.inc.pl,v 1.498 2012/03/18 06:03:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p4 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -28,27 +28,23 @@
 # ƤߤƲ
 #
 ######################################################################
-
 $::auto_meta_maxkeyword=100
 	if(!defined($::auto_meta_maxkeyword));
 $::auto_meta_minlength=5
 	if(!defined($::auto_meta_minlength));
-
-# Initlize
-
+#############################
 sub plugin_autometarobot_init {
 	return ('init'=>1, 'func'=>'meta_robots', 'meta_robots'=>\&meta_robots);
 }
-
 # hack wiki.cgi of meta_robots
-
 sub meta_robots {
 	my($cmd,$pagename,$body)=@_;
 	my $robots;
 	my $keyword;
-	if($cmd=~/edit|admin|diff|attach/
+	if($cmd=~/edit|admin|diff|attach|backup/
 		|| $::form{mypage} eq '' && $cmd!~/list|sitemap|recent/
-		|| $::form{mypage}=~/SandBox|$::resource{help}|$::resource{rulepage}|$::MenuBar|$::non_list/
+		|| $::form{mypage}=~/$::resource{help}|$::resource{rulepage}|$::RecentChanges|$::MenuBar|$::SideBar|$::TitleHeader|$::Header|$::Footer$::BodyHeader$::BodyFooter|$::SkinFooter|$::SandBox|$::InterWikiName|$::InterWikiSandBox|$::non_list/
+		|| $::meta_keyword eq "" || lc $::meta_keyword eq "disable"
 		|| &is_readable($::form{mypage}) eq 0) {
 		$robots.=<<EOD;
 <meta name="robots" content="NOINDEX,NOFOLLOW,NOARCHIVE" />
@@ -57,20 +53,17 @@ EOD
 	} else {
 		$robots.=<<EOD;
 <meta name="robots" content="INDEX,FOLLOW" />
-<meta name="googlebot" content="INDEX,FOLLOW,ARCHIVE" /> 
+<meta name="googlebot" content="INDEX,FOLLOW,ARCHIVE" />
 EOD
 		$keyword=$::meta_keyword;
 		if($::auto_meta_maxkeyword>0) {
-
 			my @keyword;
-			$keyword="$::wiki_title," . &htmlspecialchars($pagename) . ",";
-
+			$keyword="$::wiki_title,$::meta_keyword," . &htmlspecialchars($pagename) . ",";
 			foreach($body=~/(<h\d>(.+?)<\/h\d>|<strong>(.+?)<\/strong>|$::wiki_name)/g) {
 				s/[\x0d\x0a]//g;
 				s/<.*?>//g;
 				$keyword.="$_,";
 			}
-
 			foreach($body=~/<(?:a|img)(?:.+?)(?:alt|title)="(.+?)"(?:.+)>/g) {
 				next if(/^$::non_list|$::isurl/);
 				s/[\x0d\x0a]//g;
@@ -80,10 +73,9 @@ EOD
 			}
 			$keyword=~s/$::_symbol_anchor//g;
 			$keyword=~s/([\x0-\x2f|\x3a-\x40|\x5b-\x60|\x7b-\x7f]|(?:\xA1\xA1))/,/g;
-
 			my $ascii = '[\x00-\x7F]'; # 1Х EUC-JPʸ
-			my $twoBytes = '(?:[\x8E\xA1-\xFE][\xA1-\xFE])'; # 2Х EUC-JPʸ
-			my $threeBytes = '(?:\x8F[\xA1-\xFE][\xA1-\xFE])'; # 3Х EUC-JPʸ
+			my $twoBytes = '(?:[\x8E\xA1-\xFE][\xA1-\xFE])';
+			my $threeBytes = '(?:\x8F[\xA1-\xFE][\xA1-\xFE])';
 			$keyword=~s/($ascii)($twoBytes|threeBytes)/$1,$2/g;
 			$keyword=~s/($twoBytes|threeBytes)($ascii)/$1,$2/g;
 			my @keyword;
@@ -107,7 +99,6 @@ EOD
 	}
 	return $robots;
 }
-
 1;
 __DATA__
 sub plugin_autometarobot_setup {
@@ -115,7 +106,7 @@ sub plugin_autometarobot_setup {
 	'ja'=>'󥸥ư',
 	'en'=>'Auto generation keyword for robot of search engine',
 	'override'=>'meta_robots',
-	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/autometarobot/'
+	'url'=>'http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/ExPlugin/autometarobot/'
 	);
 }
 __END__
