@@ -1,30 +1,31 @@
 ######################################################################
 # color.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: color.pl,v 1.83 2011/03/02 03:05:47 papu Exp $
+# $Id: color.pl,v 1.503 2012/03/18 06:03:52 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p4 $$
-# Author: Nekyo
-# Copyright (C) 2004-2011 by Nekyo.
+# "PyukiWiki" ver 0.2.0-p3 $$
+# Author: Nekyo http://nekyo.qp.land.to/
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
-# Return:LF Code=EUC-JP 1TAB=4Spaces
+# Return:LF Code=Shift-JIS 1TAB=4Spaces
+######################################################################
+# Usage: &color(color,bgcolor) { body };
+# Usage: &color(color) { body };
+# Usage: &color(,bgcolor) { body };
+# v0.2.0-p3 : wiF݂̂̐ݒł悤ɂB
 ######################################################################
-
 use strict;
 package color;
-
 sub plugin_inline {
 	my @args = split(/,/, shift);
-	my $bgcolor = '';
 	my ($color, $bgcolor, $body);
-
 	if (@args == 3) {
 		$color = $args[0];
 		$bgcolor = $args[1];
@@ -39,14 +40,13 @@ sub plugin_inline {
 	} else {
 		return '';
 	}
-	if ($color eq '' or $body eq '') {
+	if ($color eq '' && $bgcolor eq '' || $body eq '') {
 		return '';
 	}
-	if ($bgcolor ne '') {
-		$color .= ';background-color:'.$bgcolor;
-	}
-	return "<span style=\"color:$color\">$body</span>";
+	my $style;
+	$style="color:$color" if($color ne '');
+	$style="background-color:$bgcolor" if($bgcolor ne '');
+	return "<span style=\"$style\">$body</span>";
 }
 1;
 __END__
-
