@@ -1,41 +1,34 @@
 ######################################################################
 # date.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: date.inc.pl,v 1.70 2011/03/02 03:05:47 papu Exp $
+# $Id: date.inc.pl,v 1.489 2012/03/18 06:03:52 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p4 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 use strict;
-use Time::Local;
-
 sub plugin_date_convert {
 	return &plugin_date_inline(@_);
 }
-
 sub plugin_date_inline {
 	my ($format,$date) = split(/,/, shift);
 	my ($y,$m,$d);
-
 	$format=&htmlspecialchars($format);
 	$date=&htmlspecialchars($date);
-
 	if($format eq '') {
 		return &date($::date_format);
 	}
 	$date=time if($date eq '');
-
 	if($date=~/-/) {
 		($y,$m,$d)=split(/\-/,$date);
 		$date=Time::Local::timelocal(0,0,0,$d,$m-1,$y-1900);
@@ -45,7 +38,5 @@ sub plugin_date_inline {
 	}
 	return &date($format,$date);
 }
-
 1;
 __END__
-
