@@ -1,16 +1,16 @@
 ######################################################################
 # location.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: location.inc.pl,v 1.5 2011/04/13 08:42:38 papu Exp $
+# $Id: location.inc.pl,v 1.424 2012/03/18 06:03:52 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p5 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -18,34 +18,27 @@
 ######################################################################
 # v0.1.9 2011/02/23 
 #
-#*Usage
+# *Usage
 # #location(http: or wikiڡ̾)
 #
 # ΰ١뤵ƤڡǤ¹Ԥޤ
 ######################################################################
-
 use strict;
-
-$::location::move_time=5
+$::location::move_time=3
 	if(!defined($::location::move_time));
-
 sub plugin_location_convert {
 	my $url=shift;
-
 	return if(!&is_frozen($::form{mypage}));
-
 	if(&is_exist_page($url)) {
 		my $tmp=&make_cookedurl($url);
 		$url="$::basehref$tmp";
 	}
-	$::IN_HEAD=<<EOM;
+	$::IN_HEAD.=<<EOM;
 <meta http-equiv="Refresh" content="$::location::move_time;url=$url" />
 EOM
 	my $body=$::resource{location_plugin_message};
-	$body=~s/\@\@URL\@\@/$url/g;
-
+	$body=~s/\$URL/$url/g;
 	return $body;
 }
-
 1;
 __END__
