@@ -1,41 +1,34 @@
 ######################################################################
 # time.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: time.inc.pl,v 1.76 2011/05/04 07:26:50 papu Exp $
+# $Id: time.inc.pl,v 1.488 2012/03/18 06:03:52 papu Exp $
 #
-# "PyukiWiki" version 0.1.9 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-
 use strict;
-use Time::Local;
-
 sub plugin_time_convert {
 	return &plugin_time_inline(@_);
 }
-
 sub plugin_time_inline {
 	my ($format,$time) = split(/,/, shift);
 	my ($h,$m,$s);
-
 	$format=&htmlspecialchars($format);
 	$time=&htmlspecialchars($time);
-
 	if($format eq '') {
 		return &date($::time_format);
 	}
 	$time=time if($time eq '');
-
 	if($time=~/\:/) {
 		my($sec, $min, $hour, $mday, $mon, $year,$wday, $yday, $isdst) = localtime;
 		($h,$m,$s)=split(/\:/,$time);
@@ -43,7 +36,5 @@ sub plugin_time_inline {
 	}
 	return &date($format,$time);
 }
-
 1;
 __END__
-
